@@ -18,14 +18,20 @@
 """
 import unittest
 import os
+import sys
 import shutil
 
 from zc.buildout.testing import rmdir
 
-from iw.releaser.project import archive_contents, _python, diff_releases
+from iw.releaser.project import (archive_contents, _python, 
+                                 diff_releases, _set_dynlibs, 
+                                 _extract_url)
 from iw.releaser import testing
 from iw.releaser import base
 
+from os.path import join
+curdir = os.path.dirname(__file__)
+
 class ProjectTest(unittest.TestCase):
   
     globs = {}
@@ -44,10 +50,9 @@ class ProjectTest(unittest.TestCase):
         testing.releaserTearDown(self)
          
     def test_archiving(self):         
-        
-        location = os.path.join(os.path.dirname(__file__), 'tarball')
+        location = join(os.path.dirname(__file__), 'tarball')
         #previous = self.svn_root
-        tarfile_ = os.path.join(os.path.dirname(__file__), 'pack.tgz')
+        tarfile_ = join(os.path.dirname(__file__), 'pack.tgz')
         archive_contents('pack.tgz', location) 
     
         # checking the result
@@ -59,46 +64,37 @@ class ProjectTest(unittest.TestCase):
         finally:
             tar.close()
 
-        for el in ['tarball/downloads/file2', 'tarball/file']:
+        for el in ['downloads/file2', 'file']:
             self.assert_(el in elements)
 
         os.remove(tarfile_)
 
     def test_python(self):
         # virtualenv generates python either python2.4
-        test_bin = os.path.join(os.path.dirname(__file__), 
+        test_bin = join(os.path.dirname(__file__), 
                                 'test_bin')
         os.mkdir(test_bin)
         os.chdir(test_bin)
         try:
-            os.mkdir(os.path.join(test_bin, 'bin'))
-            os.mkdir(os.path.join(test_bin, 'Scripts'))
-                
-            f = open(os.path.join(test_bin, 'bin', 'python'), 'w')
-            f.write('#')
-            f.close()
-            python = _python()    
-            self.assertEquals(python, 'bin/python')
-            os.remove(python)
-            f = open(os.path.join(test_bin, 'bin', 'python2.4'), 'w')
-            f.write('#')
-            f.close()
-            python = _python()    
-            self.assertEquals(python, 'bin/python2.4')
-            os.remove(python)
-            f = open(os.path.join(test_bin, 'Scripts', 'python'), 'w')
-            f.write('#')
-            f.close()
-            python = _python()    
-            self.assertEquals(python, 'Scripts/python')
+            os.mkdir(join(test_bin, 'bin'))
+            os.mkdir(join(test_bin, 'Scripts'))
+            
+            for place in (('bin', 'python'), 
+                          ('bin', 'python2.4'),
+                          ('bin', 'python2.4.3'),
+                          ('Scripts', 'python')):
 
+                f = open(join(test_bin, place[0], place[1]), 'w')
+                f.write('#')
+                f.close()
+                python = _python()    
+                self.assertEquals(python, join(place[0], place[1]))
+                os.remove(python)
         finally:
             shutil.rmtree(test_bin)
 
     def test_diff_releases(self):
         # making a new tarball diff
-        join = os.path.join
-
         diff_dir = join(os.path.dirname(__file__), 'diff')
         old = join(diff_dir, 'old.tgz')
         new = join(diff_dir, 'new.tgz')
@@ -112,6 +108,48 @@ class ProjectTest(unittest.TestCase):
         finally:
             if os.path.exists(res):
                 os.remove(res)
+    
+    def test_diff_releases2(self):
+        # make sure we get the tarball named autoamtically
+        # in the right place
+        diff_dir = join(os.path.dirname(__file__), 'diff')
+        old = join(diff_dir, 'old.tgz')
+        new = join(diff_dir, 'new.tgz')
+        res = join(diff_dir, 'old-to-new.tgz') 
+        wanted = join(diff_dir, 'diff.tgz')
+        try:
+            diff_releases(old, new)
+            # let's compare
+            self.assert_(open(res, 'wb'), open(wanted, 'wb'))
+        finally:
+            if os.path.exists(res):
+                os.remove(res)
+
+    def test_set_dynlibs(self):
+        old = sys.executable
+        sys.executable = os.path.join(curdir, 'python', 'python.exe')
+        try:
+            root = os.path.join(curdir, 'root')
+            _set_dynlibs(root)
+            self.assert_(os.path.exists(os.path.join(root, 'libs', 
+                                                      'libpython24.a')))
+        finally:
+            shutil.rmtree(os.path.join(root, 'libs'))
+            sys.executable = old
+
+    def test_extract_url(self):
+    
+        prot, path = _extract_url('http://svn.ingeniweb.com/pack')
+        self.assertEquals(prot, 'http://')
+        self.assertEquals(path, ['svn.ingeniweb.com', 'pack'])
+
+        prot, path = _extract_url('https://svn.ingeniweb.com/pack')
+        self.assertEquals(prot, 'https://')
+        self.assertEquals(path, ['svn.ingeniweb.com', 'pack'])
+
+        prot, path = _extract_url('svn://svn.ingeniweb.com/pack')
+        self.assertEquals(prot, 'svn://')
+        self.assertEquals(path, ['svn.ingeniweb.com', 'pack'])
 
 def test_suite():
     """returns the test suite"""
